@@ -1,5 +1,5 @@
 class Developer < User
-  has_and_belongs_to_many :projects, :include => :topics, :order => 'projects.name'
+  has_and_belongs_to_many :projects, :include => :topics, :order => 'projects.name', :join_table => 'developers_projects'
 
   def self.with_poor_ones(&block)
     with_scope :find => { :conditions => ['salary <= ?', 80000], :order => 'salary' } do
@@ -7,7 +7,9 @@ class Developer < User
     end
   end
 
-  scope :poor, :conditions => ['salary <= ?', 80000], :order => 'salary'
+  scope :poor, lambda {
+    where(['salary <= ?', 80000]).order('salary')
+  }
 
   def self.per_page() 10 end
 end
