@@ -1,12 +1,20 @@
 require 'active_support'
+begin
+  require 'minitest/unit'
+rescue LoadError
+  # Fails on Ruby 1.8, but it's OK since we only need MiniTest::Assertions
+  # on Rails 4 which doesn't support 1.8 anyway.
+end
 require 'action_dispatch/testing/assertions'
 require 'will_paginate/array'
 
 module ViewExampleGroup
   
   include ActionDispatch::Assertions::SelectorAssertions
-  
+  include MiniTest::Assertions if defined? MiniTest
+
   def assert(value, message)
+    message = message.call if message.respond_to?(:call)
     raise message unless value
   end
   
